aboutsummaryrefslogtreecommitdiffstats
path: root/test/fixedbugs/issue15611.go
diff options
context:
space:
mode:
Diffstat (limited to 'test/fixedbugs/issue15611.go')
-rw-r--r--test/fixedbugs/issue15611.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/fixedbugs/issue15611.go b/test/fixedbugs/issue15611.go
index 6a627d9b..36344754 100644
--- a/test/fixedbugs/issue15611.go
+++ b/test/fixedbugs/issue15611.go
@@ -8,13 +8,13 @@ package p
// These error messages are for the invalid literals on lines 19 and 20:
// ERROR "newline in character literal"
// ERROR "invalid character literal \(missing closing '\)"
const (
- _ = '' // ERROR "empty character literal or unescaped ' in character literal"
+ _ = '' // ERROR "empty character literal or unescaped ' in character literal|empty rune literal"
_ = 'f'
- _ = 'foo' // ERROR "invalid character literal \(more than one character\)"
+ _ = 'foo' // ERROR "invalid character literal \(more than one character\)|more than one character in rune literal"
//line issue15611.go:11
_ = '
_ = ' \ No newline at end of file
@@ -8,13 +8,13 @@ package p
// These error messages are for the invalid literals on lines 19 and 20:
-// ERROR "newline in character literal"
-// ERROR "invalid character literal \(missing closing '\)"
+// ERROR "newline in character literal|newline in rune literal"
+// ERROR "invalid character literal \(missing closing '\)|rune literal not terminated"
const (